# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from synctera_client_ng.models.finicity_account_verification import FinicityAccountVerification
from synctera_client_ng.models.manual_account_verification import ManualAccountVerification
from synctera_client_ng.models.plaid_account_verification import PlaidAccountVerification
from typing import Any, List
from pydantic import StrictStr, Field

ACCOUNTVERIFICATION_ONE_OF_SCHEMAS = ["FinicityAccountVerification", "ManualAccountVerification", "PlaidAccountVerification"]

class AccountVerification(BaseModel):
    """
    Information about the account verification process. If the account has not been verified, this will be null. 
    """
    # data type: PlaidAccountVerification
    oneof_schema_1_validator: Optional[PlaidAccountVerification] = None
    # data type: ManualAccountVerification
    oneof_schema_2_validator: Optional[ManualAccountVerification] = None
    # data type: FinicityAccountVerification
    oneof_schema_3_validator: Optional[FinicityAccountVerification] = None
    actual_instance: Any
    one_of_schemas: List[str] = Field(ACCOUNTVERIFICATION_ONE_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    discriminator_value_class_map = {
    }

    @validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        if v is None:
            return v

        instance = cls()
        error_messages = []
        match = 0
        # validate data type: PlaidAccountVerification
        if type(v) is not PlaidAccountVerification:
            error_messages.append(f"Error! Input type `{type(v)}` is not `PlaidAccountVerification`")
        else:
            match += 1

        # validate data type: ManualAccountVerification
        if type(v) is not ManualAccountVerification:
            error_messages.append(f"Error! Input type `{type(v)}` is not `ManualAccountVerification`")
        else:
            match += 1

        # validate data type: FinicityAccountVerification
        if type(v) is not FinicityAccountVerification:
            error_messages.append(f"Error! Input type `{type(v)}` is not `FinicityAccountVerification`")
        else:
            match += 1

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into AccountVerification with oneOf schemas: FinicityAccountVerification, ManualAccountVerification, PlaidAccountVerification. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into AccountVerification with oneOf schemas: FinicityAccountVerification, ManualAccountVerification, PlaidAccountVerification. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> AccountVerification:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> AccountVerification:
        """Returns the object represented by the json string"""
        instance = cls()
        if json_str is None:
            return instance

        error_messages = []
        match = 0

        # deserialize data into PlaidAccountVerification
        try:
            instance.actual_instance = PlaidAccountVerification.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into ManualAccountVerification
        try:
            instance.actual_instance = ManualAccountVerification.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into FinicityAccountVerification
        try:
            instance.actual_instance = FinicityAccountVerification.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into AccountVerification with oneOf schemas: FinicityAccountVerification, ManualAccountVerification, PlaidAccountVerification. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into AccountVerification with oneOf schemas: FinicityAccountVerification, ManualAccountVerification, PlaidAccountVerification. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_json()
        else:
            return "null"

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_dict()
        else:
            return dict()

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())

