# coding: utf-8

# flake8: noqa

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import absolute_import

__version__ = "0.41.0"

# import apis into sdk package
from synctera_client_ng.api.ach_api import ACHApi
from synctera_client_ng.api.ach_transaction_simulations_api import ACHTransactionSimulationsApi
from synctera_client_ng.api.accounts_api import AccountsApi
from synctera_client_ng.api.businesses_api import BusinessesApi
from synctera_client_ng.api.card_transaction_simulations_api import CardTransactionSimulationsApi
from synctera_client_ng.api.card_webhook_simulations_api import CardWebhookSimulationsApi
from synctera_client_ng.api.cards_api import CardsApi
from synctera_client_ng.api.cash_pickups_alpha_api import CashPickupsAlphaApi
from synctera_client_ng.api.customers_api import CustomersApi
from synctera_client_ng.api.digital_wallet_tokens_api import DigitalWalletTokensApi
from synctera_client_ng.api.disclosures_api import DisclosuresApi
from synctera_client_ng.api.disclosures_deprecated_api import DisclosuresDeprecatedApi
from synctera_client_ng.api.documents_api import DocumentsApi
from synctera_client_ng.api.external_accounts_api import ExternalAccountsApi
from synctera_client_ng.api.external_cards_api import ExternalCardsApi
from synctera_client_ng.api.internal_accounts_api import InternalAccountsApi
from synctera_client_ng.api.internal_transfer_api import InternalTransferApi
from synctera_client_ng.api.kyckyb_verifications_api import KYCKYBVerificationsApi
from synctera_client_ng.api.kyc_verification_deprecated_api import KYCVerificationDeprecatedApi
from synctera_client_ng.api.monitoring_api import MonitoringApi
from synctera_client_ng.api.notes_api import NotesApi
from synctera_client_ng.api.payment_schedules_api import PaymentSchedulesApi
from synctera_client_ng.api.persons_api import PersonsApi
from synctera_client_ng.api.relationships_api import RelationshipsApi
from synctera_client_ng.api.remote_check_deposit_beta_api import RemoteCheckDepositBetaApi
from synctera_client_ng.api.sandbox_wipe_alpha_api import SandboxWipeAlphaApi
from synctera_client_ng.api.spend_controls_beta_api import SpendControlsBetaApi
from synctera_client_ng.api.statements_api import StatementsApi
from synctera_client_ng.api.transactions_api import TransactionsApi
from synctera_client_ng.api.watchlist_deprecated_api import WatchlistDeprecatedApi
from synctera_client_ng.api.webhooks_api import WebhooksApi
from synctera_client_ng.api.wires_alpha_api import WiresAlphaApi

# import ApiClient
from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.configuration import Configuration
from synctera_client_ng.exceptions import OpenApiException
from synctera_client_ng.exceptions import ApiTypeError
from synctera_client_ng.exceptions import ApiValueError
from synctera_client_ng.exceptions import ApiKeyError
from synctera_client_ng.exceptions import ApiAttributeError
from synctera_client_ng.exceptions import ApiException
# import models into sdk package
from synctera_client_ng.models.account import Account
from synctera_client_ng.models.account_access_status import AccountAccessStatus
from synctera_client_ng.models.account_base import AccountBase
from synctera_client_ng.models.account_charge_secured import AccountChargeSecured
from synctera_client_ng.models.account_charge_secured_all_of import AccountChargeSecuredAllOf
from synctera_client_ng.models.account_creation import AccountCreation
from synctera_client_ng.models.account_creation_all_of import AccountCreationAllOf
from synctera_client_ng.models.account_depository import AccountDepository
from synctera_client_ng.models.account_depository_all_of import AccountDepositoryAllOf
from synctera_client_ng.models.account_generic_response import AccountGenericResponse
from synctera_client_ng.models.account_identifiers import AccountIdentifiers
from synctera_client_ng.models.account_line_of_credit import AccountLineOfCredit
from synctera_client_ng.models.account_line_of_credit_all_of import AccountLineOfCreditAllOf
from synctera_client_ng.models.account_list import AccountList
from synctera_client_ng.models.account_list_all_of import AccountListAllOf
from synctera_client_ng.models.account_product import AccountProduct
from synctera_client_ng.models.account_product_list import AccountProductList
from synctera_client_ng.models.account_product_list_all_of import AccountProductListAllOf
from synctera_client_ng.models.account_relationship_type import AccountRelationshipType
from synctera_client_ng.models.account_routing import AccountRouting
from synctera_client_ng.models.account_summary import AccountSummary
from synctera_client_ng.models.account_summary_balance_ceiling import AccountSummaryBalanceCeiling
from synctera_client_ng.models.account_summary_balance_floor import AccountSummaryBalanceFloor
from synctera_client_ng.models.account_template import AccountTemplate
from synctera_client_ng.models.account_template_response import AccountTemplateResponse
from synctera_client_ng.models.account_type import AccountType
from synctera_client_ng.models.account_verification import AccountVerification
from synctera_client_ng.models.accrual_payout_schedule import AccrualPayoutSchedule
from synctera_client_ng.models.ach_instruction import AchInstruction
from synctera_client_ng.models.ach_request_hold_data import AchRequestHoldData
from synctera_client_ng.models.ach_return_simulation_request import AchReturnSimulationRequest
from synctera_client_ng.models.ach_transaction_simulation_request import AchTransactionSimulationRequest
from synctera_client_ng.models.add_accounts_request import AddAccountsRequest
from synctera_client_ng.models.add_accounts_request_account_identifiers import AddAccountsRequestAccountIdentifiers
from synctera_client_ng.models.add_accounts_request_routing_identifiers import AddAccountsRequestRoutingIdentifiers
from synctera_client_ng.models.add_vendor_account_failure import AddVendorAccountFailure
from synctera_client_ng.models.add_vendor_accounts_error_reason import AddVendorAccountsErrorReason
from synctera_client_ng.models.add_vendor_accounts_request import AddVendorAccountsRequest
from synctera_client_ng.models.add_vendor_accounts_response import AddVendorAccountsResponse
from synctera_client_ng.models.additional_data import AdditionalData
from synctera_client_ng.models.additional_owner_data import AdditionalOwnerData
from synctera_client_ng.models.address import Address
from synctera_client_ng.models.address1 import Address1
from synctera_client_ng.models.address2 import Address2
from synctera_client_ng.models.adhoc_verification_request import AdhocVerificationRequest
from synctera_client_ng.models.adhoc_verification_response import AdhocVerificationResponse
from synctera_client_ng.models.apple_digital_wallet_provision_request import AppleDigitalWalletProvisionRequest
from synctera_client_ng.models.apple_digital_wallet_provision_response import AppleDigitalWalletProvisionResponse
from synctera_client_ng.models.application_type import ApplicationType
from synctera_client_ng.models.auth_request_model import AuthRequestModel
from synctera_client_ng.models.authorization_advice_model import AuthorizationAdviceModel
from synctera_client_ng.models.balance import Balance
from synctera_client_ng.models.balance_ceiling import BalanceCeiling
from synctera_client_ng.models.balance_floor import BalanceFloor
from synctera_client_ng.models.balance_inquiry_request_model import BalanceInquiryRequestModel
from synctera_client_ng.models.balance_type import BalanceType
from synctera_client_ng.models.ban_status import BanStatus
from synctera_client_ng.models.base import Base
from synctera_client_ng.models.base_account_verification import BaseAccountVerification
from synctera_client_ng.models.base_card import BaseCard
from synctera_client_ng.models.base_card_all_of import BaseCardAllOf
from synctera_client_ng.models.base_cash_pickup import BaseCashPickup
from synctera_client_ng.models.base_disclosure import BaseDisclosure
from synctera_client_ng.models.base_person import BasePerson
from synctera_client_ng.models.base_person1 import BasePerson1
from synctera_client_ng.models.base_statement import BaseStatement
from synctera_client_ng.models.base_statement_all_of import BaseStatementAllOf
from synctera_client_ng.models.base_template_fields import BaseTemplateFields
from synctera_client_ng.models.billing_address import BillingAddress
from synctera_client_ng.models.billing_period import BillingPeriod
from synctera_client_ng.models.business import Business
from synctera_client_ng.models.business1 import Business1
from synctera_client_ng.models.business_business_owner_relationship import BusinessBusinessOwnerRelationship
from synctera_client_ng.models.business_list import BusinessList
from synctera_client_ng.models.business_list_all_of import BusinessListAllOf
from synctera_client_ng.models.calculation_method import CalculationMethod
from synctera_client_ng.models.card_acceptor_model import CardAcceptorModel
from synctera_client_ng.models.card_activation_request import CardActivationRequest
from synctera_client_ng.models.card_brand import CardBrand
from synctera_client_ng.models.card_change import CardChange
from synctera_client_ng.models.card_change_state import CardChangeState
from synctera_client_ng.models.card_changes_list import CardChangesList
from synctera_client_ng.models.card_changes_list_all_of import CardChangesListAllOf
from synctera_client_ng.models.card_edit_request import CardEditRequest
from synctera_client_ng.models.card_format import CardFormat
from synctera_client_ng.models.card_fulfillment_status import CardFulfillmentStatus
from synctera_client_ng.models.card_image_details import CardImageDetails
from synctera_client_ng.models.card_image_details_list import CardImageDetailsList
from synctera_client_ng.models.card_image_details_list_all_of import CardImageDetailsListAllOf
from synctera_client_ng.models.card_image_mode import CardImageMode
from synctera_client_ng.models.card_image_rejection_reason import CardImageRejectionReason
from synctera_client_ng.models.card_image_status import CardImageStatus
from synctera_client_ng.models.card_issuance_request import CardIssuanceRequest
from synctera_client_ng.models.card_list_response import CardListResponse
from synctera_client_ng.models.card_list_response_all_of import CardListResponseAllOf
from synctera_client_ng.models.card_options import CardOptions
from synctera_client_ng.models.card_pin_status import CardPinStatus
from synctera_client_ng.models.card_product import CardProduct
from synctera_client_ng.models.card_product_all_of import CardProductAllOf
from synctera_client_ng.models.card_product_list_response import CardProductListResponse
from synctera_client_ng.models.card_product_list_response_all_of import CardProductListResponseAllOf
from synctera_client_ng.models.card_product_response import CardProductResponse
from synctera_client_ng.models.card_response import CardResponse
from synctera_client_ng.models.card_status import CardStatus
from synctera_client_ng.models.card_status_object import CardStatusObject
from synctera_client_ng.models.card_status_reason_code import CardStatusReasonCode
from synctera_client_ng.models.card_status_request import CardStatusRequest
from synctera_client_ng.models.card_widget_url_response import CardWidgetUrlResponse
from synctera_client_ng.models.cash_pickup import CashPickup
from synctera_client_ng.models.cash_pickup_all_of import CashPickupAllOf
from synctera_client_ng.models.cash_pickup_list import CashPickupList
from synctera_client_ng.models.cash_pickup_list_all_of import CashPickupListAllOf
from synctera_client_ng.models.cash_pickup_patch_request import CashPickupPatchRequest
from synctera_client_ng.models.cash_pickup_patch_request_all_of import CashPickupPatchRequestAllOf
from synctera_client_ng.models.cash_pickup_post_request import CashPickupPostRequest
from synctera_client_ng.models.cash_pickup_status import CashPickupStatus
from synctera_client_ng.models.change_channel import ChangeChannel
from synctera_client_ng.models.change_type import ChangeType
from synctera_client_ng.models.clearing_model import ClearingModel
from synctera_client_ng.models.client_token import ClientToken
from synctera_client_ng.models.create_card_image_request import CreateCardImageRequest
from synctera_client_ng.models.create_gateway_request import CreateGatewayRequest
from synctera_client_ng.models.create_secret201_response import CreateSecret201Response
from synctera_client_ng.models.customer import Customer
from synctera_client_ng.models.customer_all_of import CustomerAllOf
from synctera_client_ng.models.customer_in_body import CustomerInBody
from synctera_client_ng.models.customer_kyc_status import CustomerKycStatus
from synctera_client_ng.models.customer_list import CustomerList
from synctera_client_ng.models.customer_list_all_of import CustomerListAllOf
from synctera_client_ng.models.customer_type import CustomerType
from synctera_client_ng.models.customer_verification import CustomerVerification
from synctera_client_ng.models.customer_verification_result import CustomerVerificationResult
from synctera_client_ng.models.customer_verification_result_list import CustomerVerificationResultList
from synctera_client_ng.models.customer_verification_result_list_all_of import CustomerVerificationResultListAllOf
from synctera_client_ng.models.customer_verify_response import CustomerVerifyResponse
from synctera_client_ng.models.customer_verify_response_all_of import CustomerVerifyResponseAllOf
from synctera_client_ng.models.dc_sign import DcSign
from synctera_client_ng.models.delete_response import DeleteResponse
from synctera_client_ng.models.deposit import Deposit
from synctera_client_ng.models.deposit_list import DepositList
from synctera_client_ng.models.deposit_list_all_of import DepositListAllOf
from synctera_client_ng.models.detail import Detail
from synctera_client_ng.models.device_type import DeviceType
from synctera_client_ng.models.digital_wallet_token_address_verification import DigitalWalletTokenAddressVerification
from synctera_client_ng.models.digital_wallet_token_edit_request import DigitalWalletTokenEditRequest
from synctera_client_ng.models.digital_wallet_token_response import DigitalWalletTokenResponse
from synctera_client_ng.models.digital_wallet_token_state import DigitalWalletTokenState
from synctera_client_ng.models.digital_wallet_tokenization import DigitalWalletTokenization
from synctera_client_ng.models.direction import Direction
from synctera_client_ng.models.disclosure import Disclosure
from synctera_client_ng.models.disclosure1 import Disclosure1
from synctera_client_ng.models.disclosure_list import DisclosureList
from synctera_client_ng.models.disclosure_list_all_of import DisclosureListAllOf
from synctera_client_ng.models.disclosure_response import DisclosureResponse
from synctera_client_ng.models.disclosure_type import DisclosureType
from synctera_client_ng.models.document import Document
from synctera_client_ng.models.document_list import DocumentList
from synctera_client_ng.models.document_list_all_of import DocumentListAllOf
from synctera_client_ng.models.document_type import DocumentType
from synctera_client_ng.models.emboss_name import EmbossName
from synctera_client_ng.models.employment import Employment
from synctera_client_ng.models.employment_list import EmploymentList
from synctera_client_ng.models.employment_list_all_of import EmploymentListAllOf
from synctera_client_ng.models.encryption import Encryption
from synctera_client_ng.models.error import Error
from synctera_client_ng.models.event import Event
from synctera_client_ng.models.event_list import EventList
from synctera_client_ng.models.event_list_all_of import EventListAllOf
from synctera_client_ng.models.event_trigger import EventTrigger
from synctera_client_ng.models.event_type import EventType
from synctera_client_ng.models.event_type_explicit import EventTypeExplicit
from synctera_client_ng.models.event_type_wildcard import EventTypeWildcard
from synctera_client_ng.models.ext_account_customer_type import ExtAccountCustomerType
from synctera_client_ng.models.external_account import ExternalAccount
from synctera_client_ng.models.external_account_access_token import ExternalAccountAccessToken
from synctera_client_ng.models.external_account_balance import ExternalAccountBalance
from synctera_client_ng.models.external_account_link_token import ExternalAccountLinkToken
from synctera_client_ng.models.external_account_transaction import ExternalAccountTransaction
from synctera_client_ng.models.external_account_vendor_data import ExternalAccountVendorData
from synctera_client_ng.models.external_account_vendor_values import ExternalAccountVendorValues
from synctera_client_ng.models.external_accounts_list import ExternalAccountsList
from synctera_client_ng.models.external_accounts_list_all_of import ExternalAccountsListAllOf
from synctera_client_ng.models.external_accounts_transaction_list import ExternalAccountsTransactionList
from synctera_client_ng.models.external_card_list_response import ExternalCardListResponse
from synctera_client_ng.models.external_card_list_response_all_of import ExternalCardListResponseAllOf
from synctera_client_ng.models.external_card_request import ExternalCardRequest
from synctera_client_ng.models.external_card_response import ExternalCardResponse
from synctera_client_ng.models.external_card_verifications import ExternalCardVerifications
from synctera_client_ng.models.fee import Fee
from synctera_client_ng.models.financial_institution import FinancialInstitution
from synctera_client_ng.models.financial_request_model import FinancialRequestModel
from synctera_client_ng.models.finicity_account_verification import FinicityAccountVerification
from synctera_client_ng.models.form import Form
from synctera_client_ng.models.fulfillment_details import FulfillmentDetails
from synctera_client_ng.models.gateway_list_response import GatewayListResponse
from synctera_client_ng.models.gateway_list_response_all_of import GatewayListResponseAllOf
from synctera_client_ng.models.gateway_response import GatewayResponse
from synctera_client_ng.models.get_card_barcode200_response import GetCardBarcode200Response
from synctera_client_ng.models.google_digital_wallet_provision_request import GoogleDigitalWalletProvisionRequest
from synctera_client_ng.models.google_digital_wallet_provision_response import GoogleDigitalWalletProvisionResponse
from synctera_client_ng.models.hold_data import HoldData
from synctera_client_ng.models.in_app_provisioning import InAppProvisioning
from synctera_client_ng.models.interest import Interest
from synctera_client_ng.models.internal_account import InternalAccount
from synctera_client_ng.models.internal_account_patch import InternalAccountPatch
from synctera_client_ng.models.internal_account_post import InternalAccountPost
from synctera_client_ng.models.internal_account_post_all_of import InternalAccountPostAllOf
from synctera_client_ng.models.internal_account_purpose import InternalAccountPurpose
from synctera_client_ng.models.internal_account_response import InternalAccountResponse
from synctera_client_ng.models.internal_account_response_all_of import InternalAccountResponseAllOf
from synctera_client_ng.models.internal_account_type import InternalAccountType
from synctera_client_ng.models.internal_accounts_list import InternalAccountsList
from synctera_client_ng.models.internal_accounts_list_all_of import InternalAccountsListAllOf
from synctera_client_ng.models.internal_transfer import InternalTransfer
from synctera_client_ng.models.internal_transfer_instruction import InternalTransferInstruction
from synctera_client_ng.models.internal_transfer_patch import InternalTransferPatch
from synctera_client_ng.models.internal_transfer_response import InternalTransferResponse
from synctera_client_ng.models.internal_transfer_response_all_of import InternalTransferResponseAllOf
from synctera_client_ng.models.manual_account_verification import ManualAccountVerification
from synctera_client_ng.models.manual_entry import ManualEntry
from synctera_client_ng.models.merchant import Merchant
from synctera_client_ng.models.minimum_payment import MinimumPayment
from synctera_client_ng.models.minimum_payment_full import MinimumPaymentFull
from synctera_client_ng.models.minimum_payment_partial import MinimumPaymentPartial
from synctera_client_ng.models.minimum_payment_type import MinimumPaymentType
from synctera_client_ng.models.minimum_payment_type_full import MinimumPaymentTypeFull
from synctera_client_ng.models.minimum_payment_type_rate_or_amount import MinimumPaymentTypeRateOrAmount
from synctera_client_ng.models.monitoring_alert import MonitoringAlert
from synctera_client_ng.models.monitoring_alert_list import MonitoringAlertList
from synctera_client_ng.models.monitoring_alert_list_all_of import MonitoringAlertListAllOf
from synctera_client_ng.models.monitoring_status import MonitoringStatus
from synctera_client_ng.models.monitoring_subscription import MonitoringSubscription
from synctera_client_ng.models.monitoring_subscription_list import MonitoringSubscriptionList
from synctera_client_ng.models.monitoring_subscription_list_all_of import MonitoringSubscriptionListAllOf
from synctera_client_ng.models.network_fee_model import NetworkFeeModel
from synctera_client_ng.models.note_create import NoteCreate
from synctera_client_ng.models.note_list import NoteList
from synctera_client_ng.models.note_list_all_of import NoteListAllOf
from synctera_client_ng.models.note_response import NoteResponse
from synctera_client_ng.models.original_credit_request_model import OriginalCreditRequestModel
from synctera_client_ng.models.original_credit_sender_data import OriginalCreditSenderData
from synctera_client_ng.models.outgoing_ach import OutgoingAch
from synctera_client_ng.models.outgoing_ach_list import OutgoingAchList
from synctera_client_ng.models.outgoing_ach_list_all_of import OutgoingAchListAllOf
from synctera_client_ng.models.outgoing_ach_patch import OutgoingAchPatch
from synctera_client_ng.models.outgoing_ach_request import OutgoingAchRequest
from synctera_client_ng.models.paginated_response import PaginatedResponse
from synctera_client_ng.models.paginated_response1 import PaginatedResponse1
from synctera_client_ng.models.patch_account import PatchAccount
from synctera_client_ng.models.patch_account_charge_secured import PatchAccountChargeSecured
from synctera_client_ng.models.patch_account_charge_secured_all_of import PatchAccountChargeSecuredAllOf
from synctera_client_ng.models.patch_account_line_of_credit import PatchAccountLineOfCredit
from synctera_client_ng.models.patch_account_line_of_credit_all_of import PatchAccountLineOfCreditAllOf
from synctera_client_ng.models.patch_account_product import PatchAccountProduct
from synctera_client_ng.models.patch_accounts_request_account_identifiers import PatchAccountsRequestAccountIdentifiers
from synctera_client_ng.models.patch_accounts_request_routing_identifiers import PatchAccountsRequestRoutingIdentifiers
from synctera_client_ng.models.patch_business import PatchBusiness
from synctera_client_ng.models.patch_business_business_owner_relationship import PatchBusinessBusinessOwnerRelationship
from synctera_client_ng.models.patch_business_business_owner_relationship_all_of import PatchBusinessBusinessOwnerRelationshipAllOf
from synctera_client_ng.models.patch_customer import PatchCustomer
from synctera_client_ng.models.patch_document import PatchDocument
from synctera_client_ng.models.patch_external_account import PatchExternalAccount
from synctera_client_ng.models.patch_interest import PatchInterest
from synctera_client_ng.models.patch_note import PatchNote
from synctera_client_ng.models.patch_payment_schedule import PatchPaymentSchedule
from synctera_client_ng.models.patch_person import PatchPerson
from synctera_client_ng.models.patch_person_all_of import PatchPersonAllOf
from synctera_client_ng.models.patch_person_business_owner_relationship import PatchPersonBusinessOwnerRelationship
from synctera_client_ng.models.patch_person_business_owner_relationship_all_of import PatchPersonBusinessOwnerRelationshipAllOf
from synctera_client_ng.models.patch_person_business_relationship import PatchPersonBusinessRelationship
from synctera_client_ng.models.patch_person_business_relationship_all_of import PatchPersonBusinessRelationshipAllOf
from synctera_client_ng.models.patch_personal_id import PatchPersonalId
from synctera_client_ng.models.patch_relationship_in import PatchRelationshipIn
from synctera_client_ng.models.payment import Payment
from synctera_client_ng.models.payment_date import PaymentDate
from synctera_client_ng.models.payment_error_details import PaymentErrorDetails
from synctera_client_ng.models.payment_instruction import PaymentInstruction
from synctera_client_ng.models.payment_list import PaymentList
from synctera_client_ng.models.payment_list_all_of import PaymentListAllOf
from synctera_client_ng.models.payment_schedule import PaymentSchedule
from synctera_client_ng.models.payment_schedule_list import PaymentScheduleList
from synctera_client_ng.models.payment_schedule_list_all_of import PaymentScheduleListAllOf
from synctera_client_ng.models.payment_schedule_status import PaymentScheduleStatus
from synctera_client_ng.models.payment_status import PaymentStatus
from synctera_client_ng.models.payment_type import PaymentType
from synctera_client_ng.models.pending_transaction import PendingTransaction
from synctera_client_ng.models.pending_transaction_data import PendingTransactionData
from synctera_client_ng.models.pending_transaction_history import PendingTransactionHistory
from synctera_client_ng.models.pending_transaction_history_data import PendingTransactionHistoryData
from synctera_client_ng.models.pending_transactions import PendingTransactions
from synctera_client_ng.models.person import Person
from synctera_client_ng.models.person_business_owner_relationship import PersonBusinessOwnerRelationship
from synctera_client_ng.models.person_business_relationship import PersonBusinessRelationship
from synctera_client_ng.models.person_list import PersonList
from synctera_client_ng.models.person_list_all_of import PersonListAllOf
from synctera_client_ng.models.personal_id_base import PersonalIdBase
from synctera_client_ng.models.personal_id_country_code_post import PersonalIdCountryCodePost
from synctera_client_ng.models.personal_id_country_code_response import PersonalIdCountryCodeResponse
from synctera_client_ng.models.personal_id_customer_id import PersonalIdCustomerId
from synctera_client_ng.models.personal_id_type import PersonalIdType
from synctera_client_ng.models.physical_card import PhysicalCard
from synctera_client_ng.models.physical_card_all_of import PhysicalCardAllOf
from synctera_client_ng.models.physical_card_format import PhysicalCardFormat
from synctera_client_ng.models.physical_card_issuance_request import PhysicalCardIssuanceRequest
from synctera_client_ng.models.physical_card_plus_status import PhysicalCardPlusStatus
from synctera_client_ng.models.physical_card_response import PhysicalCardResponse
from synctera_client_ng.models.physical_card_response_all_of import PhysicalCardResponseAllOf
from synctera_client_ng.models.physical_card_response_status import PhysicalCardResponseStatus
from synctera_client_ng.models.physical_card_response_status_all_of import PhysicalCardResponseStatusAllOf
from synctera_client_ng.models.plaid_account_verification import PlaidAccountVerification
from synctera_client_ng.models.post_person import PostPerson
from synctera_client_ng.models.post_person_all_of import PostPersonAllOf
from synctera_client_ng.models.post_personal_id import PostPersonalId
from synctera_client_ng.models.post_personal_id_w_cust import PostPersonalIdWCust
from synctera_client_ng.models.post_personal_ids_array import PostPersonalIdsArray
from synctera_client_ng.models.posted_transaction import PostedTransaction
from synctera_client_ng.models.posted_transaction_data import PostedTransactionData
from synctera_client_ng.models.posted_transactions import PostedTransactions
from synctera_client_ng.models.prefill_request import PrefillRequest
from synctera_client_ng.models.prospect import Prospect
from synctera_client_ng.models.provider_type import ProviderType
from synctera_client_ng.models.provisioning_controls import ProvisioningControls
from synctera_client_ng.models.push_tokenize_request_data import PushTokenizeRequestData
from synctera_client_ng.models.rate_details import RateDetails
from synctera_client_ng.models.raw_response import RawResponse
from synctera_client_ng.models.recipient_name import RecipientName
from synctera_client_ng.models.related_resource_type import RelatedResourceType
from synctera_client_ng.models.related_resource_type1 import RelatedResourceType1
from synctera_client_ng.models.relationship import Relationship
from synctera_client_ng.models.relationship1 import Relationship1
from synctera_client_ng.models.relationship_in import RelationshipIn
from synctera_client_ng.models.relationship_list import RelationshipList
from synctera_client_ng.models.relationship_list_all_of import RelationshipListAllOf
from synctera_client_ng.models.relationship_role import RelationshipRole
from synctera_client_ng.models.relationships_list import RelationshipsList
from synctera_client_ng.models.relationships_list_all_of import RelationshipsListAllOf
from synctera_client_ng.models.replace_secret200_response import ReplaceSecret200Response
from synctera_client_ng.models.replace_secret_request import ReplaceSecretRequest
from synctera_client_ng.models.response_history_item import ResponseHistoryItem
from synctera_client_ng.models.response_person import ResponsePerson
from synctera_client_ng.models.response_personal_id import ResponsePersonalId
from synctera_client_ng.models.response_personal_id_w_cust import ResponsePersonalIdWCust
from synctera_client_ng.models.response_personal_ids_array import ResponsePersonalIdsArray
from synctera_client_ng.models.reversal_model import ReversalModel
from synctera_client_ng.models.risk_data import RiskData
from synctera_client_ng.models.risk_rating import RiskRating
from synctera_client_ng.models.risk_rating_list import RiskRatingList
from synctera_client_ng.models.risk_rating_list_all_of import RiskRatingListAllOf
from synctera_client_ng.models.savings_summary import SavingsSummary
from synctera_client_ng.models.schedule_config import ScheduleConfig
from synctera_client_ng.models.security import Security
from synctera_client_ng.models.shipping import Shipping
from synctera_client_ng.models.simulate_card_fulfillment import SimulateCardFulfillment
from synctera_client_ng.models.single_use_token_request import SingleUseTokenRequest
from synctera_client_ng.models.single_use_token_response import SingleUseTokenResponse
from synctera_client_ng.models.spend_control import SpendControl
from synctera_client_ng.models.spend_control_direction import SpendControlDirection
from synctera_client_ng.models.spend_control_response import SpendControlResponse
from synctera_client_ng.models.spend_control_response_all_of import SpendControlResponseAllOf
from synctera_client_ng.models.spend_control_response_list import SpendControlResponseList
from synctera_client_ng.models.spend_control_response_list_all_of import SpendControlResponseListAllOf
from synctera_client_ng.models.spend_control_rolling_window_days import SpendControlRollingWindowDays
from synctera_client_ng.models.spend_control_rolling_window_days_all_of import SpendControlRollingWindowDaysAllOf
from synctera_client_ng.models.spend_control_time_range import SpendControlTimeRange
from synctera_client_ng.models.spend_control_time_range_type import SpendControlTimeRangeType
from synctera_client_ng.models.spend_control_update_request import SpendControlUpdateRequest
from synctera_client_ng.models.spending_limit_with_time import SpendingLimitWithTime
from synctera_client_ng.models.spending_limits import SpendingLimits
from synctera_client_ng.models.spending_limits_transaction import SpendingLimitsTransaction
from synctera_client_ng.models.ssn_source import SsnSource
from synctera_client_ng.models.statement import Statement
from synctera_client_ng.models.statement_all_of import StatementAllOf
from synctera_client_ng.models.statement_list import StatementList
from synctera_client_ng.models.statement_list_all_of import StatementListAllOf
from synctera_client_ng.models.statement_summary import StatementSummary
from synctera_client_ng.models.status import Status
from synctera_client_ng.models.status1 import Status1
from synctera_client_ng.models.status2 import Status2
from synctera_client_ng.models.template_fields import TemplateFields
from synctera_client_ng.models.template_fields_charge_secured import TemplateFieldsChargeSecured
from synctera_client_ng.models.template_fields_charge_secured_all_of import TemplateFieldsChargeSecuredAllOf
from synctera_client_ng.models.template_fields_depository import TemplateFieldsDepository
from synctera_client_ng.models.template_fields_depository_all_of import TemplateFieldsDepositoryAllOf
from synctera_client_ng.models.template_fields_generic_response import TemplateFieldsGenericResponse
from synctera_client_ng.models.template_fields_line_of_credit import TemplateFieldsLineOfCredit
from synctera_client_ng.models.template_fields_line_of_credit_all_of import TemplateFieldsLineOfCreditAllOf
from synctera_client_ng.models.template_list import TemplateList
from synctera_client_ng.models.template_list_all_of import TemplateListAllOf
from synctera_client_ng.models.three_ds_policy import ThreeDsPolicy
from synctera_client_ng.models.token_list import TokenList
from synctera_client_ng.models.token_list_response import TokenListResponse
from synctera_client_ng.models.transaction import Transaction
from synctera_client_ng.models.transaction_data import TransactionData
from synctera_client_ng.models.transaction_line import TransactionLine
from synctera_client_ng.models.transaction_line1 import TransactionLine1
from synctera_client_ng.models.transaction_list import TransactionList
from synctera_client_ng.models.transaction_list_all_of import TransactionListAllOf
from synctera_client_ng.models.transaction_options import TransactionOptions
from synctera_client_ng.models.transfer_list_response import TransferListResponse
from synctera_client_ng.models.transfer_list_response_all_of import TransferListResponseAllOf
from synctera_client_ng.models.transfer_request import TransferRequest
from synctera_client_ng.models.transfer_request_base import TransferRequestBase
from synctera_client_ng.models.transfer_request_pull import TransferRequestPull
from synctera_client_ng.models.transfer_request_pull_all_of import TransferRequestPullAllOf
from synctera_client_ng.models.transfer_request_push import TransferRequestPush
from synctera_client_ng.models.transfer_request_push_all_of import TransferRequestPushAllOf
from synctera_client_ng.models.transfer_response import TransferResponse
from synctera_client_ng.models.transfer_response_base import TransferResponseBase
from synctera_client_ng.models.transfer_response_pull import TransferResponsePull
from synctera_client_ng.models.transfer_response_push import TransferResponsePush
from synctera_client_ng.models.transfer_reversal_request import TransferReversalRequest
from synctera_client_ng.models.transfer_type import TransferType
from synctera_client_ng.models.transfer_type_request import TransferTypeRequest
from synctera_client_ng.models.trigger_event_request import TriggerEventRequest
from synctera_client_ng.models.txn_enhancer import TxnEnhancer
from synctera_client_ng.models.type import Type
from synctera_client_ng.models.update_card_image_request import UpdateCardImageRequest
from synctera_client_ng.models.update_gateway_request import UpdateGatewayRequest
from synctera_client_ng.models.update_transfer import UpdateTransfer
from synctera_client_ng.models.vendor_info import VendorInfo
from synctera_client_ng.models.vendor_info1 import VendorInfo1
from synctera_client_ng.models.vendor_json import VendorJson
from synctera_client_ng.models.vendor_xml import VendorXml
from synctera_client_ng.models.verification import Verification
from synctera_client_ng.models.verification_all_of import VerificationAllOf
from synctera_client_ng.models.verification_list import VerificationList
from synctera_client_ng.models.verification_list_all_of import VerificationListAllOf
from synctera_client_ng.models.verification_request import VerificationRequest
from synctera_client_ng.models.verification_request_all_of import VerificationRequestAllOf
from synctera_client_ng.models.verification_result import VerificationResult
from synctera_client_ng.models.verification_status import VerificationStatus
from synctera_client_ng.models.verification_type import VerificationType
from synctera_client_ng.models.verification_type1 import VerificationType1
from synctera_client_ng.models.verification_vendor_info import VerificationVendorInfo
from synctera_client_ng.models.verification_vendor_info_detail import VerificationVendorInfoDetail
from synctera_client_ng.models.verification_vendor_json import VerificationVendorJson
from synctera_client_ng.models.verification_vendor_xml import VerificationVendorXml
from synctera_client_ng.models.verify_response import VerifyResponse
from synctera_client_ng.models.verify_response_all_of import VerifyResponseAllOf
from synctera_client_ng.models.virtual_card import VirtualCard
from synctera_client_ng.models.virtual_card_all_of import VirtualCardAllOf
from synctera_client_ng.models.virtual_card_issuance_request import VirtualCardIssuanceRequest
from synctera_client_ng.models.virtual_card_plus_status import VirtualCardPlusStatus
from synctera_client_ng.models.virtual_card_response import VirtualCardResponse
from synctera_client_ng.models.virtual_card_response_all_of import VirtualCardResponseAllOf
from synctera_client_ng.models.virtual_card_response_status import VirtualCardResponseStatus
from synctera_client_ng.models.wallet_provider_card_on_file import WalletProviderCardOnFile
from synctera_client_ng.models.watchlist_alert import WatchlistAlert
from synctera_client_ng.models.watchlist_alert_list import WatchlistAlertList
from synctera_client_ng.models.watchlist_alert_list_all_of import WatchlistAlertListAllOf
from synctera_client_ng.models.watchlist_subscription import WatchlistSubscription
from synctera_client_ng.models.watchlist_subscription_list import WatchlistSubscriptionList
from synctera_client_ng.models.watchlist_subscription_list_all_of import WatchlistSubscriptionListAllOf
from synctera_client_ng.models.watchlist_suppress import WatchlistSuppress
from synctera_client_ng.models.webhook import Webhook
from synctera_client_ng.models.webhook_list import WebhookList
from synctera_client_ng.models.webhook_list_all_of import WebhookListAllOf
from synctera_client_ng.models.webhook_request_object import WebhookRequestObject
from synctera_client_ng.models.widget_type import WidgetType
from synctera_client_ng.models.wire import Wire
from synctera_client_ng.models.wire_list import WireList
from synctera_client_ng.models.wire_list_all_of import WireListAllOf
from synctera_client_ng.models.wire_request import WireRequest
from synctera_client_ng.models.withdrawal_request_model import WithdrawalRequestModel
