# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class MinimumPaymentTypeRateOrAmount(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    min_amount: StrictInt = Field(..., description="The minimum amount to charge as a minimum payment, in cents. For example, to set the minimum to $30, set this value to 3000. Note: despite setting this value, the minimum payment will never be greater than the statement balance. ")
    rate: StrictInt = Field(..., description="The percentage of the balance to use, in basis points. For example, to set 12.5% of the balance, set this value to 1250. ")
    type: StrictStr = ...
    __properties = ["min_amount", "rate", "type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MinimumPaymentTypeRateOrAmount:
        """Create an instance of MinimumPaymentTypeRateOrAmount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MinimumPaymentTypeRateOrAmount:
        """Create an instance of MinimumPaymentTypeRateOrAmount from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MinimumPaymentTypeRateOrAmount.parse_obj(obj)

        _obj = MinimumPaymentTypeRateOrAmount.parse_obj({
            "min_amount": obj.get("min_amount"),
            "rate": obj.get("rate"),
            "type": obj.get("type")
        })
        return _obj

