# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardStatus(str, Enum):
    """
    The status indicating the card lifecycle state
    """

    """
    allowed enum values
    """
    ACTIVE = 'ACTIVE'
    UNACTIVATED = 'UNACTIVATED'
    SUSPENDED = 'SUSPENDED'
    TERMINATED = 'TERMINATED'
    IMAGE_PENDING = 'IMAGE_PENDING'
    IMAGE_REJECTED = 'IMAGE_REJECTED'

