# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class VerificationType1(str, Enum):
    """
    The verification run on the customer. One the following:   * `IDENTITY` – verify that the information provided is associated with the identity of a real person or business.   * `WATCHLIST` – checks watchlists for known fraud, money laundering, and other suspicious activity.   * `RELATED_ENTITIES` – represents dependent verification checks for related parties (e.g. all beneficial owners must pass KYC for a business to pass KYB).   * `MANUAL_REVIEW` – represents the outcome of a manual review of the verification done on a party (note: overrides the outcome of other verification types). 
    """

    """
    allowed enum values
    """
    IDENTITY = 'IDENTITY'
    WATCHLIST = 'WATCHLIST'
    RELATED_ENTITIES = 'RELATED_ENTITIES'
    MANUAL_REVIEW = 'MANUAL_REVIEW'

